==> cloud-4.0.0-alpha1.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Service/OpenStackRestServiceMock.php <==
<?php

namespace Drupal\openstack\Service;

use Drupal\openstack\Service\Rest\OpenStackService;
use Drupal\Core\Form\ConfigFormBaseTrait;

/**
 * OpenStackRestServiceMock service interacts with the OpenStack API.
 */
class OpenStackRestServiceMock extends OpenStackService {

  use ConfigFormBaseTrait;

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['openstack.settings'];
  }

  /**
   * Generate auth token.
   *
   * @param array $credentials
   *   The credentials array.
   *
   * @return array
   *   Return auth token API response.
   */
  public function generateAuthToken(array $credentials = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get Instance List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance list API response.
   */
  public function describeInstances(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance update API response.
   */
  public function modifyLaunchTemplate(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Start Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance Start API response.
   */
  public function startInstances(array $params = []): bool {
    return TRUE;
  }

  /**
   * Stop Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance Stop API response.
   */
  public function stopInstances(array $params = []): bool {
    return TRUE;
  }

  /**
   * Reboot Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance Reboot API response.
   */
  public function rebootInstances(array $params = []): bool {
    return TRUE;
  }

  /**
   * Terminate|Delete Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance Terminate|Delete API response.
   */
  public function terminateInstance(array $params = []): bool {
    return TRUE;
  }

  /**
   * Delete tags.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return bool
   *   The delete instance list API response.
   */
  public function deleteTags(array $params = []): bool {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function describeImages(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create Image List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Image create API response.
   */
  public function createImage(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update Image List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Image update API response.
   */
  public function updateImage(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete Image List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Image delete API response.
   */
  public function deregisterImage(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create Tags.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return bool
   *   The Tags create API response.
   */
  public function createTags(array $params = []): bool {
    return TRUE;
  }

  /**
   * Get key pairs List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The key pairs list API response.
   */
  public function describeKeyPairs(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create key pairs List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The key pairs create API response.
   */
  public function createKeyPair(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Import key pairs List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The key pairs import API response.
   */
  public function importKeyPair(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete key pairs List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   Succeeded or failed.
   */
  public function deleteKeyPair(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get volume list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The volume list API response.
   */
  public function describeVolumes(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The volume create API response.
   */
  public function createVolume(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The volume update API response.
   */
  public function updateVolume(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return bool
   *   Succeeded or failed.
   */
  public function deleteVolume(array $params = []): bool {
    return TRUE;
  }

  /**
   * Attach volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return bool
   *   Succeeded or failed.
   */
  public function attachVolume(array $params = []): bool {
    return TRUE;
  }

  /**
   * Detach volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return bool
   *   Succeeded or failed.
   */
  public function detachVolume(array $params = []): bool {
    return TRUE;
  }

  /**
   * Get snapshot list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The snapshot list API response.
   */
  public function describeSnapshots(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create snapshot.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The snapshot create API response.
   */
  public function createSnapshot(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update snapshot.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The snapshot update API response.
   */
  public function updateSnapshot(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete snapshot.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   Succeeded or failed.
   */
  public function deleteSnapshot(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get flavors.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Flavor list API response.
   */
  public function describeFlavors(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get Flavor Detail of specific flavor Id.
   *
   * @param array $params
   *   Parameters to pass to the API.
   * @param string $flavor_id
   *   The Flavor Id.
   *
   * @return array
   *   The Flavor list API response.
   */
  public function describeFlavorById(array $params = [], $flavor_id = ''): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get volume Detail of specific volume Id.
   *
   * @param array $params
   *   Parameters to pass to the API.
   * @param string $volume_id
   *   The Volume Id.
   *
   * @return array
   *   The volume list API response.
   */
  public function describeVolumeById(array $params = [], $volume_id = ''): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get security group list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The security group list API response.
   */
  public function describeSecurityGroups(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create security group list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The security group create API response.
   */
  public function createSecurityGroup(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update security group List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The security group update API response.
   */
  public function updateSecurityGroup(array $params = []):array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete security group List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   Succeeded or failed.
   */
  public function deleteSecurityGroup(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create security group Rule.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The security group rule create API response.
   */
  public function createSecurityGroupRule(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Revoke security group list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   Succeeded or failed.
   */
  public function revokeSecurityGroupRule(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get Subnet Detail.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Subnet Detail list API response.
   */
  public function describeSubnetDetail(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get network interface list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The network interface list API response.
   */
  public function describeNetworkInterfaces(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create network interface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The network interface create API response.
   */
  public function createNetworkInterface(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update network interface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The network interface update API response.
   */
  public function updateNetworkInterface(array $params = []):array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete network interface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return bool
   *   Succeeded or failed.
   */
  public function deleteNetworkInterface(array $params = []): bool {
    return TRUE;
  }

  /**
   * Get Floating IP List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Floating IP list API response.
   */
  public function describeAddresses(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create Floating IP.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Floating IP create API response.
   */
  public function allocateAddress(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Associate Floating IP.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Floating IP associate API response.
   */
  public function associateAddress(array $params = []):array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Disassociate Floating IP.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Floating IP associate API response.
   */
  public function disassociateAddress(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Instance Port Interface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance Port Interface list API response.
   */
  public function instancePortInterface(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get NetworkInterface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The NetworkInterface list API response.
   */
  public function describeNetworkInterfacesPorts(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete Floating IP.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Floating IP delete API response.
   */
  public function releaseAddress(array $params = []): bool {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function describeAvailabilityZones(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * {@inheritdoc}
   */
  public function getAvailabilityZones($with_id = FALSE, array $credentials = []): array {
    $result = $this->describeAvailabilityZones([], $credentials);
    if (!empty($result)) {
      foreach ($result['AvailabilityZones'] ?: [] as $zone_info) {
        if ($with_id) {
          $name = sprintf('%s (%s)', $zone_info['ZoneName'], $zone_info['ZoneId']);
        }
        else {
          $name = $zone_info['ZoneName'];
        }
        $zones[$zone_info['ZoneName']] = $name;
      }
    }
    return $zones;
  }

  /**
   * Run instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   * @param array $tags
   *   The tags array.
   *
   * @return array
   *   The create instance list API response.
   */
  public function runInstances(array $params = [], array $tags = []): bool {
    return TRUE;
  }

  /**
   * Get mock data for a method.
   *
   * @param string $method_name
   *   The method name.
   *
   * @return array
   *   An array of the mock data for a method.
   */
  private function getMockData($method_name): array {
    return json_decode($this->config('openstack.settings')->get('openstack_mock_data'), TRUE)[ucfirst($method_name)] ?? [];
  }

}

==> cloud-5.0.0-alpha1.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Service/OpenStackRestServiceMock.php <==
<?php

namespace Drupal\openstack\Service;

use Drupal\openstack\Service\Rest\OpenStackService;
use Drupal\Core\Form\ConfigFormBaseTrait;

/**
 * OpenStackRestServiceMock service interacts with the OpenStack API.
 */
class OpenStackRestServiceMock extends OpenStackService {

  use ConfigFormBaseTrait;

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['openstack.settings'];
  }

  /**
   * Generate auth token.
   *
   * @param array $credentials
   *   The credentials array.
   *
   * @return array
   *   Return auth token API response.
   */
  public function generateAuthToken(array $credentials = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get Instance List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance list API response.
   */
  public function describeInstances(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance update API response.
   */
  public function modifyLaunchTemplate(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Start Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   The Instance Start API response.
   */
  public function startInstances(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Stop Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   The Instance Stop API response.
   */
  public function stopInstances(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Reboot Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   The Instance Reboot API response.
   */
  public function rebootInstances(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Terminate|Delete Instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   The Instance Terminate|Delete API response.
   */
  public function terminateInstances(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Delete tags.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   The delete instance list API response.
   */
  public function deleteTags(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * {@inheritdoc}
   */
  public function describeImages(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create Image List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Image create API response.
   */
  public function createImage(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update Image List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Image update API response.
   */
  public function updateImage(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete Image List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   The Image delete API response.
   */
  public function deregisterImage(array $params = []): ?array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create Tags.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   The Tags create API response.
   */
  public function createTags(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Get key pairs List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The key pairs list API response.
   */
  public function describeKeyPairs(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create key pairs List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The key pairs create API response.
   */
  public function createKeyPair(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Import key pairs List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The key pairs import API response.
   */
  public function importKeyPair(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete key pairs List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   Succeeded or failed.
   */
  public function deleteKeyPair(array $params = []): ?array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get volume list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The volume list API response.
   */
  public function describeVolumes(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The volume create API response.
   */
  public function createVolume(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The volume update API response.
   */
  public function updateVolume(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   Succeeded or failed.
   */
  public function deleteVolume(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Attach volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   Succeeded or failed.
   */
  public function attachVolume(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Detach volume.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   Succeeded or failed.
   */
  public function detachVolume(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Get snapshot list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The snapshot list API response.
   */
  public function describeSnapshots(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create snapshot.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The snapshot create API response.
   */
  public function createSnapshot(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update snapshot.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The snapshot update API response.
   */
  public function updateSnapshot(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete snapshot.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   Succeeded or failed.
   */
  public function deleteSnapshot(array $params = []): ?array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get flavors.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Flavor list API response.
   */
  public function describeFlavors(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get Flavor Detail of specific flavor Id.
   *
   * @param array $params
   *   Parameters to pass to the API.
   * @param string $flavor_id
   *   The Flavor Id.
   *
   * @return array
   *   The Flavor list API response.
   */
  public function describeFlavorById(array $params = [], $flavor_id = ''): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get volume Detail of specific volume Id.
   *
   * @param array $params
   *   Parameters to pass to the API.
   * @param string $volume_id
   *   The Volume Id.
   *
   * @return array
   *   The volume list API response.
   */
  public function describeVolumeById(array $params = [], $volume_id = ''): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get security group list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The security group list API response.
   */
  public function describeSecurityGroups(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create security group list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The security group create API response.
   */
  public function createSecurityGroup(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update security group List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The security group update API response.
   */
  public function updateSecurityGroup(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete security group List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   Succeeded or failed.
   */
  public function deleteSecurityGroup(array $params = []): ?array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create security group Rule.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The security group rule create API response.
   */
  public function createSecurityGroupRule(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Revoke security group list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   Succeeded or failed.
   */
  public function revokeSecurityGroupRule(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get Subnet Detail.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Subnet Detail list API response.
   */
  public function describeSubnetDetail(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get network interface list.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The network interface list API response.
   */
  public function describeNetworkInterfaces(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create network interface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The network interface create API response.
   */
  public function createNetworkInterface(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Update network interface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The network interface update API response.
   */
  public function updateNetworkInterface(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete network interface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   Succeeded or failed.
   */
  public function deleteNetworkInterface(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Get Floating IP List.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Floating IP list API response.
   */
  public function describeAddresses(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Create Floating IP.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Floating IP create API response.
   */
  public function allocateAddress(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Associate Floating IP.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Floating IP associate API response.
   */
  public function associateAddress(array $params = []):array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Disassociate Floating IP.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Floating IP associate API response.
   */
  public function disassociateAddress(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Instance Port Interface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The Instance Port Interface list API response.
   */
  public function instancePortInterface(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Get NetworkInterface.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array
   *   The NetworkInterface list API response.
   */
  public function describeNetworkInterfacesPorts(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * Delete Floating IP.
   *
   * @param array $params
   *   Parameters to pass to the API.
   *
   * @return array|null
   *   The Floating IP delete API response.
   */
  public function releaseAddress(array $params = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * {@inheritdoc}
   */
  public function describeAvailabilityZones(array $params = []): array {
    return $this->getMockData(__FUNCTION__);
  }

  /**
   * {@inheritdoc}
   */
  public function getAvailabilityZones($with_id = FALSE, array $credentials = []): array {
    $result = $this->describeAvailabilityZones([], $credentials);
    if (!empty($result)) {
      foreach ($result['AvailabilityZones'] ?: [] as $zone_info) {
        $zones[$zone_info['ZoneName']] = $zone_info['ZoneName'];
      }
    }
    return $zones;
  }

  /**
   * Run instance.
   *
   * @param array $params
   *   Parameters to pass to the API.
   * @param array $tags
   *   The tags array.
   *
   * @return array|null
   *   The create instance list API response.
   */
  public function runInstances(array $params = [], array $tags = []): ?array {
    return ['Success' => TRUE];
  }

  /**
   * Get mock data for a method.
   *
   * @param string $method_name
   *   The method name.
   *
   * @return array
   *   An array of the mock data for a method.
   */
  private function getMockData($method_name): array {
    return json_decode($this->config('openstack.settings')->get('openstack_mock_data'), TRUE)[ucfirst($method_name)] ?? [];
  }

}
